/**
 * @license
 * Copyright 2018 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */

import summary from "rollup-plugin-summary";
import { terser } from "rollup-plugin-terser";
import resolve from "@rollup/plugin-node-resolve";
import replace from "@rollup/plugin-replace";
import babel from "@rollup/plugin-babel";
import minifyHTML from "rollup-plugin-minify-html-literals";
// import commonjs from "@rollup/plugin-commonjs";
// import postcss from "rollup-plugin-postcss";
export default {
  input: "./transpiled/dev-console-widget.js",
  output: {
    file: "./build/dev-console-widget.bundle.js",
    format: "esm",
  },
  onwarn(warning) {
    if (warning.code !== "THIS_IS_UNDEFINED") {
      console.error(`(!) ${warning.message}`);
    }
  },
  plugins: [
    replace({ "Reflect.decorate": "undefined", preventAssignment: true }),
    resolve(),
    minifyHTML(),
    terser({
      ecma: 2017,
      module: true,
      warnings: true,
      mangle: {
        properties: {
          regex: /^__/,
        },
      },
    }),
    babel({
      babelHelpers: "bundled",
      presets: [
        [
          require.resolve("@babel/preset-env"),
          {
            targets: {
              edge: "17",
              firefox: "60",
              chrome: "67",
              safari: "11.1",
            },
            modules: false,
            bugfixes: true,
            // useBuiltIns: "usage",
            // corejs: "3.6.5",
          },
        ],
      ],
    }),
    summary(),
  ],
};
